@@ -9,7 +9,7 @@ select_engine.register(passes.AnnotateRepLinks)
 #select_engine.register(passes.DebugVisualizer)
 select_engine.register(passes.PrePeepHole)
 select_engine.register(passes.CreateExpressions)
-select_engine.register(passes.WrapperPlanner,debug_mode=False)
+select_engine.register(passes.WrapperPlanner,debug_mode=True)
 #select_engine.register(passes.DebugVisualizer)
 select_engine.register(passes.PythonPeepHole)
 select_engine.register(passes.SerializeExec)
